@@ -1,5 +1,5 @@
 Perms <-
-function(n)
+function(n)#generated matrix of all possible combos of predictors in tree
 {
   mat<-matrix(0, nrow=2^n, ncol=n)
   for(i in 1:n)
